# 0 "decode.h"
# 0 "<built-in>"
# 0 "<command-line>"
# 1 "/usr/include/stdc-predef.h" 1 3 4
# 0 "<command-line>" 2
# 1 "decode.h"
# 1 "gen.h" 1
# 2 "decode.h" 2

int wrap_0_89(class CL12 *uc, t_mem code) { return uc-> adc ( _A_i8 ); }
int wrap_0_99(class CL12 *uc, t_mem code) { return uc-> adc ( _A_dop ); }
int wrap_0_a9(class CL12 *uc, t_mem code) { return uc-> adc ( _A_xbop8 ); }
int wrap_0_b9(class CL12 *uc, t_mem code) { return uc-> adc ( _A_eop ); }

int wrap_0_c9(class CL12 *uc, t_mem code) { return uc-> adc ( _B_i8 ); }
int wrap_0_d9(class CL12 *uc, t_mem code) { return uc-> adc ( _B_dop ); }
int wrap_0_e9(class CL12 *uc, t_mem code) { return uc-> adc ( _B_xbop8 ); }
int wrap_0_f9(class CL12 *uc, t_mem code) { return uc-> adc ( _B_eop ); }

int wrap_0_8b(class CL12 *uc, t_mem code) { return uc-> add ( _A_i8 ); }
int wrap_0_9b(class CL12 *uc, t_mem code) { return uc-> add ( _A_dop ); }
int wrap_0_ab(class CL12 *uc, t_mem code) { return uc-> add ( _A_xbop8 ); }
int wrap_0_bb(class CL12 *uc, t_mem code) { return uc-> add ( _A_eop ); }

int wrap_0_cb(class CL12 *uc, t_mem code) { return uc-> add ( _B_i8 ); }
int wrap_0_db(class CL12 *uc, t_mem code) { return uc-> add ( _B_dop ); }
int wrap_0_eb(class CL12 *uc, t_mem code) { return uc-> add ( _B_xbop8 ); }
int wrap_0_fb(class CL12 *uc, t_mem code) { return uc-> add ( _B_eop ); }

int wrap_0_84(class CL12 *uc, t_mem code) { return uc-> And ( _A_i8 ); }
int wrap_0_94(class CL12 *uc, t_mem code) { return uc-> And ( _A_dop ); }
int wrap_0_a4(class CL12 *uc, t_mem code) { return uc-> And ( _A_xbop8 ); }
int wrap_0_b4(class CL12 *uc, t_mem code) { return uc-> And ( _A_eop ); }

int wrap_0_c4(class CL12 *uc, t_mem code) { return uc-> And ( _B_i8 ); }
int wrap_0_d4(class CL12 *uc, t_mem code) { return uc-> And ( _B_dop ); }
int wrap_0_e4(class CL12 *uc, t_mem code) { return uc-> And ( _B_xbop8 ); }
int wrap_0_f4(class CL12 *uc, t_mem code) { return uc-> And ( _B_eop ); }

int wrap_0_88(class CL12 *uc, t_mem code) { return uc-> eor ( _A_i8 ); }
int wrap_0_98(class CL12 *uc, t_mem code) { return uc-> eor ( _A_dop ); }
int wrap_0_a8(class CL12 *uc, t_mem code) { return uc-> eor ( _A_xbop8 ); }
int wrap_0_b8(class CL12 *uc, t_mem code) { return uc-> eor ( _A_eop ); }

int wrap_0_c8(class CL12 *uc, t_mem code) { return uc-> eor ( _B_i8 ); }
int wrap_0_d8(class CL12 *uc, t_mem code) { return uc-> eor ( _B_dop ); }
int wrap_0_e8(class CL12 *uc, t_mem code) { return uc-> eor ( _B_xbop8 ); }
int wrap_0_f8(class CL12 *uc, t_mem code) { return uc-> eor ( _B_eop ); }

int wrap_0_8a(class CL12 *uc, t_mem code) { return uc-> Or ( _A_i8 ); }
int wrap_0_9a(class CL12 *uc, t_mem code) { return uc-> Or ( _A_dop ); }
int wrap_0_aa(class CL12 *uc, t_mem code) { return uc-> Or ( _A_xbop8 ); }
int wrap_0_ba(class CL12 *uc, t_mem code) { return uc-> Or ( _A_eop ); }

int wrap_0_ca(class CL12 *uc, t_mem code) { return uc-> Or ( _B_i8 ); }
int wrap_0_da(class CL12 *uc, t_mem code) { return uc-> Or ( _B_dop ); }
int wrap_0_ea(class CL12 *uc, t_mem code) { return uc-> Or ( _B_xbop8 ); }
int wrap_0_fa(class CL12 *uc, t_mem code) { return uc-> Or ( _B_eop ); }

int wrap_0_85(class CL12 *uc, t_mem code) { return uc-> bit ( _Aop_i8 ); }
int wrap_0_95(class CL12 *uc, t_mem code) { return uc-> bit ( _Aop_dop ); }
int wrap_0_a5(class CL12 *uc, t_mem code) { return uc-> bit ( _Aop_xbop8 ); }
int wrap_0_b5(class CL12 *uc, t_mem code) { return uc-> bit ( _Aop_eop ); }

int wrap_0_c5(class CL12 *uc, t_mem code) { return uc-> bit ( _Bop_i8 ); }
int wrap_0_d5(class CL12 *uc, t_mem code) { return uc-> bit ( _Bop_dop ); }
int wrap_0_e5(class CL12 *uc, t_mem code) { return uc-> bit ( _Bop_xbop8 ); }
int wrap_0_f5(class CL12 *uc, t_mem code) { return uc-> bit ( _Bop_eop ); }

int wrap_0_81(class CL12 *uc, t_mem code) { return uc-> cmp ( _Aop_i8 ); }
int wrap_0_91(class CL12 *uc, t_mem code) { return uc-> cmp ( _Aop_dop ); }
int wrap_0_a1(class CL12 *uc, t_mem code) { return uc-> cmp ( _Aop_xbop8 ); }
int wrap_0_b1(class CL12 *uc, t_mem code) { return uc-> cmp ( _Aop_eop ); }

int wrap_0_c1(class CL12 *uc, t_mem code) { return uc-> cmp ( _Bop_i8 ); }
int wrap_0_d1(class CL12 *uc, t_mem code) { return uc-> cmp ( _Bop_dop ); }
int wrap_0_e1(class CL12 *uc, t_mem code) { return uc-> cmp ( _Bop_xbop8 ); }
int wrap_0_f1(class CL12 *uc, t_mem code) { return uc-> cmp ( _Bop_eop ); }

int wrap_0_80(class CL12 *uc, t_mem code) { return uc-> sub ( _A_i8 ); }
int wrap_0_90(class CL12 *uc, t_mem code) { return uc-> sub ( _A_dop ); }
int wrap_0_a0(class CL12 *uc, t_mem code) { return uc-> sub ( _A_xbop8 ); }
int wrap_0_b0(class CL12 *uc, t_mem code) { return uc-> sub ( _A_eop ); }

int wrap_0_c0(class CL12 *uc, t_mem code) { return uc-> sub ( _B_i8 ); }
int wrap_0_d0(class CL12 *uc, t_mem code) { return uc-> sub ( _B_dop ); }
int wrap_0_e0(class CL12 *uc, t_mem code) { return uc-> sub ( _B_xbop8 ); }
int wrap_0_f0(class CL12 *uc, t_mem code) { return uc-> sub ( _B_eop ); }

int wrap_0_82(class CL12 *uc, t_mem code) { return uc-> sbc ( _A_i8 ); }
int wrap_0_92(class CL12 *uc, t_mem code) { return uc-> sbc ( _A_dop ); }
int wrap_0_a2(class CL12 *uc, t_mem code) { return uc-> sbc ( _A_xbop8 ); }
int wrap_0_b2(class CL12 *uc, t_mem code) { return uc-> sbc ( _A_eop ); }

int wrap_0_c2(class CL12 *uc, t_mem code) { return uc-> sbc ( _B_i8 ); }
int wrap_0_d2(class CL12 *uc, t_mem code) { return uc-> sbc ( _B_dop ); }
int wrap_0_e2(class CL12 *uc, t_mem code) { return uc-> sbc ( _B_xbop8 ); }
int wrap_0_f2(class CL12 *uc, t_mem code) { return uc-> sbc ( _B_eop ); }

int wrap_0_86(class CL12 *uc, t_mem code) { return uc-> lda ( _A_i8 ); }
int wrap_0_96(class CL12 *uc, t_mem code) { return uc-> lda ( _A_dop ); }
int wrap_0_a6(class CL12 *uc, t_mem code) { return uc-> lda ( _A_xbop8 ); }
int wrap_0_b6(class CL12 *uc, t_mem code) { return uc-> lda ( _A_eop ); }

int wrap_0_c6(class CL12 *uc, t_mem code) { return uc-> lda ( _B_i8 ); }
int wrap_0_d6(class CL12 *uc, t_mem code) { return uc-> lda ( _B_dop ); }
int wrap_0_e6(class CL12 *uc, t_mem code) { return uc-> lda ( _B_xbop8 ); }
int wrap_0_f6(class CL12 *uc, t_mem code) { return uc-> lda ( _B_eop ); }

int wrap_0_83(class CL12 *uc, t_mem code) { return uc-> sub16 ( _D_i16 ); }
int wrap_0_93(class CL12 *uc, t_mem code) { return uc-> sub16 ( _D_dop16 ); }
int wrap_0_a3(class CL12 *uc, t_mem code) { return uc-> sub16 ( _D_xbop16 ); }
int wrap_0_b3(class CL12 *uc, t_mem code) { return uc-> sub16 ( _D_eop16 ); }

int wrap_0_8c(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Dop_i16 ); }
int wrap_0_9c(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Dop_dop16 ); }
int wrap_0_ac(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Dop_xbop16 ); }
int wrap_0_bc(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Dop_eop16 ); }

int wrap_0_8d(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Yop_i16 ); }
int wrap_0_9d(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Yop_dop16 ); }
int wrap_0_ad(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Yop_xbop16 ); }
int wrap_0_bd(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Yop_eop16 ); }

int wrap_0_8e(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Xop_i16 ); }
int wrap_0_9e(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Xop_dop16 ); }
int wrap_0_ae(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Xop_xbop16 ); }
int wrap_0_be(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Xop_eop16 ); }

int wrap_0_8f(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Sop_i16 ); }
int wrap_0_9f(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Sop_dop16 ); }
int wrap_0_af(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Sop_xbop16 ); }
int wrap_0_bf(class CL12 *uc, t_mem code) { return uc-> cp16 ( _Sop_eop16 ); }

int wrap_0_c3(class CL12 *uc, t_mem code) { return uc-> add16 ( _D_i16 ); }
int wrap_0_d3(class CL12 *uc, t_mem code) { return uc-> add16 ( _D_dop16 ); }
int wrap_0_e3(class CL12 *uc, t_mem code) { return uc-> add16 ( _D_xbop16 ); }
int wrap_0_f3(class CL12 *uc, t_mem code) { return uc-> add16 ( _D_eop16 ); }

int wrap_0_cc(class CL12 *uc, t_mem code) { return uc-> ld16 ( _D_i16 ); }
int wrap_0_dc(class CL12 *uc, t_mem code) { return uc-> ld16 ( _D_dop16 ); }
int wrap_0_ec(class CL12 *uc, t_mem code) { return uc-> ld16 ( _D_xbop16 ); }
int wrap_0_fc(class CL12 *uc, t_mem code) { return uc-> ld16 ( _D_eop16 ); }

int wrap_0_ce(class CL12 *uc, t_mem code) { return uc-> ld16 ( _X_i16 ); }
int wrap_0_de(class CL12 *uc, t_mem code) { return uc-> ld16 ( _X_dop16 ); }
int wrap_0_ee(class CL12 *uc, t_mem code) { return uc-> ld16 ( _X_xbop16 ); }
int wrap_0_fe(class CL12 *uc, t_mem code) { return uc-> ld16 ( _X_eop16 ); }

int wrap_0_cd(class CL12 *uc, t_mem code) { return uc-> ld16 ( _Y_i16 ); }
int wrap_0_dd(class CL12 *uc, t_mem code) { return uc-> ld16 ( _Y_dop16 ); }
int wrap_0_ed(class CL12 *uc, t_mem code) { return uc-> ld16 ( _Y_xbop16 ); }
int wrap_0_fd(class CL12 *uc, t_mem code) { return uc-> ld16 ( _Y_eop16 ); }

int wrap_0_cf(class CL12 *uc, t_mem code) { return uc-> ld16 ( _S_i16 ); }
int wrap_0_df(class CL12 *uc, t_mem code) { return uc-> ld16 ( _S_dop16 ); }
int wrap_0_ef(class CL12 *uc, t_mem code) { return uc-> ld16 ( _S_xbop16 ); }
int wrap_0_ff(class CL12 *uc, t_mem code) { return uc-> ld16 ( _S_eop16 ); }

int wrap_0_87(class CL12 *uc, t_mem code) { return uc-> clr ( _cA ); }
int wrap_0_c7(class CL12 *uc, t_mem code) { return uc-> clr ( _cB ); }
int wrap_0_69(class CL12 *uc, t_mem code) { return uc-> clr ( _xb ); }
int wrap_0_79(class CL12 *uc, t_mem code) { return uc-> clr ( _e ); }

int wrap_0_97(class CL12 *uc, t_mem code) { return uc-> tst ( _Aop ); }
int wrap_0_d7(class CL12 *uc, t_mem code) { return uc-> tst ( _Bop ); }
int wrap_0_e7(class CL12 *uc, t_mem code) { return uc-> tst ( _xbop8 ); }
int wrap_0_f7(class CL12 *uc, t_mem code) { return uc-> tst ( _eop ); }

int wrap_0_40(class CL12 *uc, t_mem code) { return uc-> neg ( _cA ); }
int wrap_0_50(class CL12 *uc, t_mem code) { return uc-> neg ( _cB ); }
int wrap_0_60(class CL12 *uc, t_mem code) { return uc-> neg ( _xb ); }
int wrap_0_70(class CL12 *uc, t_mem code) { return uc-> neg ( _e ); }

int wrap_0_41(class CL12 *uc, t_mem code) { return uc-> com ( _cA ); }
int wrap_0_51(class CL12 *uc, t_mem code) { return uc-> com ( _cB ); }
int wrap_0_61(class CL12 *uc, t_mem code) { return uc-> com ( _xb ); }
int wrap_0_71(class CL12 *uc, t_mem code) { return uc-> com ( _e ); }

int wrap_0_42(class CL12 *uc, t_mem code) { return uc-> inc ( _cA ); }
int wrap_0_52(class CL12 *uc, t_mem code) { return uc-> inc ( _cB ); }
int wrap_0_62(class CL12 *uc, t_mem code) { return uc-> inc ( _xb ); }
int wrap_0_72(class CL12 *uc, t_mem code) { return uc-> inc ( _e ); }

int wrap_0_43(class CL12 *uc, t_mem code) { return uc-> dec ( _cA ); }
int wrap_0_53(class CL12 *uc, t_mem code) { return uc-> dec ( _cB ); }
int wrap_0_63(class CL12 *uc, t_mem code) { return uc-> dec ( _xb ); }
int wrap_0_73(class CL12 *uc, t_mem code) { return uc-> dec ( _e ); }

int wrap_0_44(class CL12 *uc, t_mem code) { return uc-> lsr ( _cA ); }
int wrap_0_54(class CL12 *uc, t_mem code) { return uc-> lsr ( _cB ); }
int wrap_0_64(class CL12 *uc, t_mem code) { return uc-> lsr ( _xb ); }
int wrap_0_74(class CL12 *uc, t_mem code) { return uc-> lsr ( _e ); }

int wrap_0_45(class CL12 *uc, t_mem code) { return uc-> rol ( _cA ); }
int wrap_0_55(class CL12 *uc, t_mem code) { return uc-> rol ( _cB ); }
int wrap_0_65(class CL12 *uc, t_mem code) { return uc-> rol ( _xb ); }
int wrap_0_75(class CL12 *uc, t_mem code) { return uc-> rol ( _e ); }

int wrap_0_46(class CL12 *uc, t_mem code) { return uc-> ror ( _cA ); }
int wrap_0_56(class CL12 *uc, t_mem code) { return uc-> ror ( _cB ); }
int wrap_0_66(class CL12 *uc, t_mem code) { return uc-> ror ( _xb ); }
int wrap_0_76(class CL12 *uc, t_mem code) { return uc-> ror ( _e ); }

int wrap_0_47(class CL12 *uc, t_mem code) { return uc-> asr ( _cA ); }
int wrap_0_57(class CL12 *uc, t_mem code) { return uc-> asr ( _cB ); }
int wrap_0_67(class CL12 *uc, t_mem code) { return uc-> asr ( _xb ); }
int wrap_0_77(class CL12 *uc, t_mem code) { return uc-> asr ( _e ); }

int wrap_0_48(class CL12 *uc, t_mem code) { return uc-> asl ( _cA ); }
int wrap_0_58(class CL12 *uc, t_mem code) { return uc-> asl ( _cB ); }
int wrap_0_68(class CL12 *uc, t_mem code) { return uc-> asl ( _xb ); }
int wrap_0_78(class CL12 *uc, t_mem code) { return uc-> asl ( _e ); }

int wrap_0_49(class CL12 *uc, t_mem code) { return uc-> lsr16 ( _cD ); }
int wrap_0_59(class CL12 *uc, t_mem code) { return uc-> asl16 ( _cD ); }

int wrap_0_4a(class CL12 *uc, t_mem code) { return uc-> call_e ( _NONE ); }
int wrap_0_4b(class CL12 *uc, t_mem code) { return uc-> call_id ( _NONE ); }

int wrap_0_5a(class CL12 *uc, t_mem code) { return uc-> sta ( _d_Aop ); }
int wrap_0_6a(class CL12 *uc, t_mem code) { return uc-> sta ( _xb_Aop ); }
int wrap_0_7a(class CL12 *uc, t_mem code) { return uc-> sta ( _e_Aop ); }

int wrap_0_5b(class CL12 *uc, t_mem code) { return uc-> sta ( _d_Bop ); }
int wrap_0_6b(class CL12 *uc, t_mem code) { return uc-> sta ( _xb_Bop ); }
int wrap_0_7b(class CL12 *uc, t_mem code) { return uc-> sta ( _e_Bop ); }

int wrap_0_5c(class CL12 *uc, t_mem code) { return uc-> stsx ( _da_Dop ); }
int wrap_0_6c(class CL12 *uc, t_mem code) { return uc-> stsx ( _xba_Dop ); }
int wrap_0_7c(class CL12 *uc, t_mem code) { return uc-> stsx ( _ea_Dop ); }

int wrap_0_5e(class CL12 *uc, t_mem code) { return uc-> stsx ( _da_Xop ); }
int wrap_0_6e(class CL12 *uc, t_mem code) { return uc-> stsx ( _xba_Xop ); }
int wrap_0_7e(class CL12 *uc, t_mem code) { return uc-> stsx ( _ea_Xop ); }

int wrap_0_5d(class CL12 *uc, t_mem code) { return uc-> stsx ( _da_Yop ); }
int wrap_0_6d(class CL12 *uc, t_mem code) { return uc-> stsx ( _xba_Yop ); }
int wrap_0_7d(class CL12 *uc, t_mem code) { return uc-> stsx ( _ea_Yop ); }

int wrap_0_5f(class CL12 *uc, t_mem code) { return uc-> stsx ( _da_Sop ); }
int wrap_0_6f(class CL12 *uc, t_mem code) { return uc-> stsx ( _xba_Sop ); }
int wrap_0_7f(class CL12 *uc, t_mem code) { return uc-> stsx ( _ea_Sop ); }

int wrap_0_4c(class CL12 *uc, t_mem code) { return uc-> Or ( _d_i8 ); }
int wrap_0_0c(class CL12 *uc, t_mem code) { return uc-> Or ( _xb_i8 ); }
int wrap_0_1c(class CL12 *uc, t_mem code) { return uc-> Or ( _e_i8 ); }

int wrap_0_4d(class CL12 *uc, t_mem code) { return uc-> And ( _d_i8n ); }
int wrap_0_0d(class CL12 *uc, t_mem code) { return uc-> And ( _xb_i8n ); }
int wrap_0_1d(class CL12 *uc, t_mem code) { return uc-> And ( _e_i8n ); }

int wrap_0_4e(class CL12 *uc, t_mem code) { return uc-> brset_d ( _NONE ); }
int wrap_0_0e(class CL12 *uc, t_mem code) { return uc-> brset_id ( _NONE ); }
int wrap_0_1e(class CL12 *uc, t_mem code) { return uc-> brset_e ( _NONE ); }

int wrap_0_4f(class CL12 *uc, t_mem code) { return uc-> brclr_d ( _NONE ); }
int wrap_0_0f(class CL12 *uc, t_mem code) { return uc-> brclr_id ( _NONE ); }
int wrap_0_1f(class CL12 *uc, t_mem code) { return uc-> brclr_e ( _NONE ); }

int wrap_0_20(class CL12 *uc, t_mem code) { return uc-> BRA ( 0x20 ); }
int wrap_0_21(class CL12 *uc, t_mem code) { return uc-> BRN ( 0x21 ); }
int wrap_0_22(class CL12 *uc, t_mem code) { return uc-> BHI ( 0x22 ); }
int wrap_0_23(class CL12 *uc, t_mem code) { return uc-> BLS ( 0x23 ); }
int wrap_0_24(class CL12 *uc, t_mem code) { return uc-> BCC ( 0x24 ); }
int wrap_0_25(class CL12 *uc, t_mem code) { return uc-> BCS ( 0x25 ); }
int wrap_0_26(class CL12 *uc, t_mem code) { return uc-> BNE ( 0x26 ); }
int wrap_0_27(class CL12 *uc, t_mem code) { return uc-> BEQ ( 0x27 ); }
int wrap_0_28(class CL12 *uc, t_mem code) { return uc-> BVC ( 0x28 ); }
int wrap_0_29(class CL12 *uc, t_mem code) { return uc-> BVS ( 0x29 ); }
int wrap_0_2a(class CL12 *uc, t_mem code) { return uc-> BPL ( 0x2a ); }
int wrap_0_2b(class CL12 *uc, t_mem code) { return uc-> BMI ( 0x2b ); }
int wrap_0_2c(class CL12 *uc, t_mem code) { return uc-> BGE ( 0x2c ); }
int wrap_0_2d(class CL12 *uc, t_mem code) { return uc-> BLT ( 0x2d ); }
int wrap_0_2e(class CL12 *uc, t_mem code) { return uc-> BGT ( 0x2e ); }
int wrap_0_2f(class CL12 *uc, t_mem code) { return uc-> BLE ( 0x2f ); }

int wrap_0_30(class CL12 *uc, t_mem code) { return uc-> i_pul16 ( _cX ); }
int wrap_0_31(class CL12 *uc, t_mem code) { return uc-> i_pul16 ( _cY ); }
int wrap_0_32(class CL12 *uc, t_mem code) { return uc-> i_pul8 ( _cA ); }
int wrap_0_33(class CL12 *uc, t_mem code) { return uc-> i_pul8 ( _cB ); }
int wrap_0_34(class CL12 *uc, t_mem code) { return uc-> i_psh16 ( _Xop ); }
int wrap_0_35(class CL12 *uc, t_mem code) { return uc-> i_psh16 ( _Yop ); }
int wrap_0_36(class CL12 *uc, t_mem code) { return uc-> i_psh8 ( _Aop ); }
int wrap_0_37(class CL12 *uc, t_mem code) { return uc-> i_psh8 ( _Bop ); }
int wrap_0_38(class CL12 *uc, t_mem code) { return uc-> i_pul8 ( _cC ); }
int wrap_0_39(class CL12 *uc, t_mem code) { return uc-> i_psh8 ( _Cop ); }
int wrap_0_3a(class CL12 *uc, t_mem code) { return uc-> i_pul16 ( _cD ); }
int wrap_0_3b(class CL12 *uc, t_mem code) { return uc-> i_psh16 ( _Dop ); }

int wrap_0_a7(class CL12 *uc, t_mem code) { return uc-> NOP ( 0xa7 ); }

int wrap_0_b7(class CL12 *uc, t_mem code) { return uc-> exec_b7 ( _NONE ); }

int wrap_0x18_06(class CL12 *uc, t_mem code) { return uc-> add ( _A_B ); }
